load_openproblems
datasets.load_openproblems(task)
Load a bundled OpenProblems task as a method by dataset by metric tensor.
Parameters
| Name | Type | Description | Default |
|---|---|---|---|
task |
str | One of the bundled task ids: "batch_integration" (19 methods, 6 datasets, 13 scIB metrics) or "spatially_variable_genes" (14 methods, 50 datasets, one correlation metric). |
required |
Returns
| Type | Description |
|---|---|
| OpenProblems |
Raises
| Type | Description |
|---|---|
| ValueError | If task is not one of the bundled tasks. |